@@ -1,10 +1,12 @@
+import logging
+
 from event_stream.models.model import *
 from sqlalchemy import Table, Column, MetaData, create_engine
 import os
 import urllib
 import psycopg2
 from sqlalchemy.exc import IntegrityError
-from sqlalchemy.orm import sessionmaker
+from sqlalchemy.orm import sessionmaker, scoped_session
 
 
 class DAO(object):
@@ -25,16 +27,19 @@ class DAO(object):
         Base.metadata.create_all(engine)
         # database = databases.Database(DATABASE_URL)
 
-        Session = sessionmaker(bind=engine)
+        # Session = sessionmaker(bind=engine)
+        session_factory = sessionmaker(bind=engine)
+        Session = scoped_session(session_factory)
         self.session = Session()
 
     def save_object(self, obj):
-        try:
-            self.session.add(obj)
-            return self.session.commit()
-        except IntegrityError:
-            self.session.rollback()
-        return None
+        # try:
+        self.session.add(obj)
+        self.session.commit()
+        # except IntegrityError:
+        #     print('error')
+        #     self.session.rollback()
+
 
     def get_object(self, table, key):
         result = self.session.query(table).filter_by(**key).first()
@@ -43,14 +48,12 @@ class DAO(object):
         return result
 
     def save_if_not_exist(self, obj, table, kwargs):
-        if id not in obj:
-            obj_db = self.get_object(table, kwargs)
-            if obj_db:
-                print('does exists')
-                return obj_db
-            else:
-                print('does not exists')
-                return self.save_object(obj)
+        obj_db = self.get_object(table, kwargs)
+        if obj_db:
+            return obj_db
+
+        self.save_object(obj)
+        return obj
 
     def get_publication(self, doi):
         return self.get_object(Publication, {'doi': doi})
@@ -64,30 +67,42 @@ class DAO(object):
                                   normalizedTitle=publication_data['normalizedTitle'],
                                   abstract=publication_data['abstract'])
         publication = self.save_if_not_exist(publication, Publication, {'doi': publication.doi})
+        logging.warning('publication.doi')
+        logging.warning(publication.doi)
+        logging.warning(publication.id)
 
         authors = publication_data['authors']
         for author_data in authors:
             author = Author(name=author_data['name'], normalizedName=author_data['normalizedName'])
 
             author = self.save_if_not_exist(author, Author, {'normalizedName': author.normalizedName})
-
-            publication_authors = PublicationAuthor(**{'authorId': author.id, 'publicationDoi': publication.doi})
-            self.save_object(publication_authors)
+            logging.warning('author.id')
+            logging.warning(author.id)
+            if author.id:
+                publication_authors = PublicationAuthor(**{'authorId': author.id, 'publicationDoi': publication.doi})
+                self.save_if_not_exist(publication_authors, PublicationAuthor, {'authorId': author.id, 'publicationDoi': publication.doi})
 
         sources = publication_data['source_id']
         for sources_data in sources:
-            source = Source(title=sources_data['title'], url=sources_data['url'])
+            source = Source(title=sources_data['title'], url=sources_data['url']) # todo no doi url ?
             source = self.save_if_not_exist(source, Source, {'title': source.title})
-            publication_sources = PublicationSource(**{'sourceId': source.id, 'publicationDoi': publication.doi})
-            self.save_object(publication_sources)
+            logging.warning('source.id')
+            logging.warning(source.id)
+            if source.id:
+                publication_sources = PublicationSource(**{'sourceId': source.id, 'publicationDoi': publication.doi})
+                self.save_if_not_exist(publication_sources, PublicationSource, {'sourceId': source.id, 'publicationDoi': publication.doi})
 
-        fields_of_study = publication_data['fieldOfStudy']
-        for fos_data in fields_of_study:
-            fos = FieldOfStudy(name=fos_data['name'], normalizedName=fos_data['normalizedName'])
-            fos.level = 2
-            fos = self.save_if_not_exist(fos, FieldOfStudy, {'normalizedName': fos.normalizedName})
-            publication_fos = PublicationFieldOfStudy(**{'fieldOfStudyId': fos.id, 'publicationDoi': publication.doi})
-            self.save_object(publication_fos)
+        if 'fieldsOfStudy' in publication_data:
+            fields_of_study = publication_data['fieldsOfStudy']
+            for fos_data in fields_of_study:
+                fos = FieldOfStudy(name=fos_data['name'], normalizedName=fos_data['normalizedName'])
+                fos.level = 2
+                fos = self.save_if_not_exist(fos, FieldOfStudy, {'normalizedName': fos.normalizedName})
+                logging.warning('fos.id')
+                logging.warning(fos.id)
+                if fos.id:
+                    publication_fos = PublicationFieldOfStudy(**{'fieldOfStudyId': fos.id, 'publicationDoi': publication.doi})
+                    self.save_if_not_exist(publication_fos, PublicationFieldOfStudy, {'fieldOfStudyId': fos.id, 'publicationDoi': publication.doi})
 
         return publication
         # todo
