@@ -67,7 +67,7 @@ class EventStreamBase(object):
         self.id = id_in
         self.counter = counter_in
         self.log = self.log + str(self.id) + ": "
-        self.bootstrap_servers = [os.environ['KAFKA_BOOTRSTRAP_SERVER']]
+        self.bootstrap_servers = [os.environ.get('KAFKA_BOOTRSTRAP_SERVER', 'kafka:9092')]
 
     def build_topic_list(self):
         """build a list of topics from the configs
